aboutsummaryrefslogtreecommitdiff
path: root/velocity-engine-core/src/main/java/org/apache/velocity/runtime/RuntimeConstants.java
diff options
context:
space:
mode:
authorClaude Brisson <cbrisson@apache.org>2019-03-03 17:47:32 +0000
committerClaude Brisson <cbrisson@apache.org>2019-03-03 17:47:32 +0000
commite6bc7dc9661efabf26a8aade5b546829bc8667dd (patch)
tree235e92ee80e0477770facd14ba03d5cb3fcfca3c /velocity-engine-core/src/main/java/org/apache/velocity/runtime/RuntimeConstants.java
parentd24fbe2c5729ad26f99462dd689cd3effb677dc0 (diff)
downloadapache-velocity-engine-e6bc7dc9661efabf26a8aade5b546829bc8667dd.tar.gz
[engine] Don't mix hyphens with dashes ; use '_' for word separator in corresponding property name
git-svn-id: https://svn.apache.org/repos/asf/velocity/engine/trunk@1854737 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'velocity-engine-core/src/main/java/org/apache/velocity/runtime/RuntimeConstants.java')
-rw-r--r--velocity-engine-core/src/main/java/org/apache/velocity/runtime/RuntimeConstants.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/velocity-engine-core/src/main/java/org/apache/velocity/runtime/RuntimeConstants.java b/velocity-engine-core/src/main/java/org/apache/velocity/runtime/RuntimeConstants.java
index 3ffa3362..b5d3c0f3 100644
--- a/velocity-engine-core/src/main/java/org/apache/velocity/runtime/RuntimeConstants.java
+++ b/velocity-engine-core/src/main/java/org/apache/velocity/runtime/RuntimeConstants.java
@@ -305,10 +305,10 @@ public interface RuntimeConstants
String PARSER_POOL_SIZE = "parser.pool.size";
/**
* Allow dash in identifiers (backward compatibility option)
* @since 2.1
*/
- String PARSER_DASH_ALLOWED = "parser.allows.dash.in.identifiers";
+ String PARSER_HYPHEN_ALLOWED = "parser.allow_hyphen_in_identifiers";
/**
* Space gobbling mode
@@ -305,10 +305,10 @@ public interface RuntimeConstants
String PARSER_POOL_SIZE = "parser.pool.size";
/**
- * Allow dash in identifiers (backward compatibility option)
+ * Allow hyphen in identifiers (backward compatibility option)
* @since 2.1
*/